#
# spec file for package release-notes-sled
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define SUSE_PROD SUSE_Linux_Enterprise_Desktop_15
# "lifecycle" changes the document profiling, accepted values:
#   beta | maintained | unmaintained
%define lifecycle maintained
Name:           release-notes-sled
Version:        15.5.20230301
Release:        150500.3.3.1
Summary:        Release Notes for SUSE Linux Enterprise Desktop
License:        CC-BY-ND-4.0
Group:          Documentation/SUSE
URL:            https://www.suse.com/releasenotes/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  daps
BuildRequires:  suse-xsl-stylesheets >= 1.9.18
BuildRequires:  update-desktop-files
BuildRequires:  w3m
Requires:       dejavu-fonts
Requires:       google-opensans-fonts
Provides:       release-notes() = SLED
BuildArch:      noarch

%description
This package contains the release notes for SUSE Linux Enterprise Desktop/SUSE
Linux Enterprise Workstation Extension.
After installing this package, the release notes files can be
found in the %{_datadir}/doc/release-notes directory. The release notes
are available in the following output formats: PDF, HTML, and TXT.

%prep
%setup -q

%build
sed -i 's/@VERSION@/%{version}/' adoc/release-notes-docinfo.xml adoc/attributes-generic.adoc
%make_build all LIFECYCLE=%{lifecycle}

%install
rnpath=%{buildroot}%{_datadir}/doc/release-notes/%{SUSE_PROD}
install -m 0644 -D LICENSE ${rnpath}/LICENSE
install -m 0644 -D "build/release-notes/html/release-notes/index.html" "${rnpath}/RELEASE-NOTES.en.html"
install -m 0644 -D "build/release-notes/html/release-notes/changelog.html" "${rnpath}"
cp -R "build/release-notes/html/release-notes/static/" "${rnpath}"
install -m 0644 -D "build/release-notes/yast-html/release-notes.html" "${rnpath}/RELEASE-NOTES.en.rtf"
install -m 0644 -D "build/release-notes/release-notes_color_en.pdf" "${rnpath}/RELEASE-NOTES.en.pdf"
install -m 0644 -D "build/release-notes/release-notes.txt" "${rnpath}/RELEASE-NOTES.en.txt"

%files
%doc %{_datadir}/doc/release-notes/

%changelog
* Wed Jun 14 2023 lukas.kucharczyk@suse.com
- Set lifecycle to maintained (tracked in bsc#933411)
* Wed Mar  1 2023 lukas.kucharczyk@suse.com
- 15.5.20230301 (tracked in bsc#933411)
- Added note about WSL installation (jsc#PED-1863)
* Wed Jan  4 2023 lukas.kucharczyk@suse.com
- 15.5.20230104 (tracked in bsc#933411)
- Added note about Evolution folder move confirmation (jsc#PED-1582)
* Wed Nov 30 2022 lukas.kucharczyk@suse.com
- 15.5.20221130 (tracked in bsc#933411)
- Fix product version, report bug links
* Tue Oct 18 2022 lukas.kucharczyk@suse.com
- 15.5.20221018 (tracked in bsc#933411)
- Initial version
* Wed May 11 2022 lukas.kucharczyk@suse.com
- 15.4.20220511 (tracked in bsc#933411)
- Added changelog
- Added note about insserv-compat migration failure (bsc#1194837)
- Added note about Firefox FTP support removal (bsc#1198973)
- Added note about gnome-documents deprecation (bsc#1197374)
* Wed Nov  3 2021 lukas.kucharczyk@suse.com
- 15.4.20211103 (tracked in bsc#933411)
- Initial SP4 release
* Wed May  5 2021 lukas.kucharczyk@suse.com
- 15.3.20210505 (tracked in bsc#933411)
- Change Bugzilla references
- Update branding (jsc#SLE-14772)
* Wed Apr 21 2021 lukas.kucharczyk@suse.com
- 15.3.20210421 (tracked in bsc#933411)
- Added note about updated packages and modules (jsc#SLE-17332)
* Wed Mar 10 2021 lukas.kucharczyk@suse.com
- 15.3.20210310
- Added note about improved scanner support (jsc#SLE-15561)
- Added note about WPA3 support in wpa_supplicant (jsc#SLE-14992)
- Added note about Remmina update (jsc#SLE-16217)
- Added note about Strongswan support in NetworkManager (jsc#SLE-5556)
- Added note about Flatpak update (jsc#SLE-17238)
* Wed Jan 27 2021 lukas@localhost
- 15.3.20210127
- Added note about laptop pattern renaming to mobile
  (jsc#SLE-11520)
* Tue Nov 17 2020 sknorr@suse.com
- 15.3.20201117 (bsc#933411)
- Initial release notes for SLED 15 SP3
* Fri Jun  5 2020 sknorr@suse.com
- 15.2.20200605 (bsc#933411)
- Use the term "Online Documentation"
- Add Modules/Extensions/Related Products section
- Fix displayed month of 15 SP2 release
* Thu Feb 20 2020 sknorr@suse.com
- 15.2.20200220
- Added note that GNOME Session Restore is now disabled
  (bsc#1158851)
- Added note about PRIME render offload (jsc#SLE-8470)
- Added note about Pidgin Rocket.Chat plug-in (jsc#SLE-7747)
* Tue Feb  4 2020 sknorr@suse.com
- 15.2.20200204 (tracked in bsc#933411)
- Initial notes for SLED/SLE-WE 15 SP2
- Migrate to AsciiDoc as source format
- Add notes on Desktop, Vagrant, systemd (jsc#SLE-7743,
  jsc#SLE-8244, jsc#SLE-7747, jsc#SLE-8085, jsc#SLE-9610,
  jsc#SLE-5552)
* Thu May  2 2019 sknorr@suse.com
- 15.1.20190502
- Updated template text
- New notes:
  - GNOME Initial Setup (gnome-initial-setup) Provides User
    Configuration (FATE#325763)
  - resolv.conf Is Now Located in /run (FATE#325872)
  - HiDPI support in GNOME (FATE#326682)
- Document fixes and changed notes:
  - Updated version numbers in list of shipped packages
    (bsc#1122484)
  - Support for Socket-Based Services Activation (FATE#319428)
* Thu May  2 2019 sknorr@suse.com
- Remove bad Provides line from spec (bsc#1130834)
* Fri Dec 14 2018 sknorr@suse.com
- 15.1.20181214
- New notes:
  - Support for Socket-Based Services Activation (FATE#319428)
  - Displaying Disk Space Used by Snapper Snapshots (FATE#323843)
* Fri Sep 28 2018 sknorr@suse.com
- 15.1.20180928 (tracked in bsc#933411)
- Updated Makefile
- Updated template text
- Updated release notes from FATE
* Tue Jul 17 2018 sknorr@suse.com
- 15.0.20180717 (tracked in bsc#1101511)
- Updated template text
  - Include SLE-WE in displayed product name (bsc#1096359)
- Updated release notes from FATE
- New notes:
  - The User Space X Drivers cirrus/mga/ast Have Been Removed
    (FATE#325795, requested via bsc#1089319)
  - Using Thunderbolt Devices (FATE#325796, requested via
    bsc#1090199)
  - Updated Btrfs Subvolume Layout (FATE#325797, requested via
    bsc#1085628)
* Tue Jun  5 2018 sknorr@suse.com
- 15.0.20180605 (tracked in bsc#1054478)
- Added provides to fix Release Notes display in installer
  (bsc#1054478)
- Updated template text
  - Fixed deprecations time frame (bsc#1087249)
- Updated release notes from FATE
- New entries:
  - ReiserFS Support Removed (FATE#323394)
  - Plymouth/GDM May Hang If No Display Is Connected (FATE#325753)
* Fri May 18 2018 sknorr@suse.com
- 15.0.20180518 (15.0 GMC)
- Updated release notes from FATE
- New entries:
  - Graphics Chipset Compatibility under Wayland (FATE#325703)
    [bsc#1093306]
- Changed entries:
  - firewalld Replaces SuSEfirewall2 as Default Software Firewall
    (FATE#320794)
  - ntpd Has Been Replaced With Chrony (FATE#323432)
- Removed entries:
  - ReiserFS Support Removed (FATE#323394)
* Fri Apr 27 2018 sknorr@suse.com
- 15.0.20180427
- Updated release notes from FATE
- New entries:
  - firewalld Replaces SuSEfirewall2 as Default Software Firewall
    (FATE#320794)
  - All SLE 15 Packages Are Enabled for Address Space Layout
    Randomization (FATE#322473)
  - Enigmail Extension Provided for OpenPGP Support in Mozilla
    Thunderbird (FATE#325486)
- Changed entries:
  - System-wide Locale/Keymap/Font Settings are not read from
    /etc/sysconfig/ anymore (FATE#319454)
* Mon Apr  9 2018 sknorr@suse.com
- 15.0.20180409
- Updated release notes from FATE
- New entries:
  - Mozilla Thunderbird Provided as a Cross-Platform E-Mail Client
    (FATE#323869)
- Changed entries:
  - UnRAR Has Been Replaced by unar (FATE#323896)
  - wodim Has Been Replaced by cdrtools (FATE#324159)
  - Parted Supports Linux-Specific GPT GUID for Partitions
    (FATE#325468)
* Mon Mar 19 2018 sknorr@suse.com
- 15.0.20180319
- Updated release notes from FATE
- New entries:
  - Wayland Cannot Be Used on Machines with Hybrid GPUs (FATE#316497,
    bsc#1067321)
  - Legacy Module: ntpd is now part of the Legacy Module (FATE#323411)
  - wodim Has Been Replaced by cdrtools (FATE#324159)
  - Drivers for Nvidia GPUs (FATE#325453)
  - Parted Supports Linux-Specific GPT GUID for Partitions (FATE#325468)
- Changed entries:
  - ntpd Has Been Replaced With Chrony (FATE#323432)
* Mon Mar 12 2018 sknorr@suse.com
- 15.0.20180312
- Updated template text
- Updated release notes from FATE
- New entries:
  - Support for AMD Memory Encryption (FATE#322123)
  - Support for AMD Secure Encrypted Virtualization (FATE#322124)
  - Support for Nested Virtualization Performance Features in Newer
    AMD Processors (FATE#323405)
  - UnRAR Has Been Replaced by unar (FATE#323896)
- Changed entries:
  - ntpd Has Been Replaced With Chrony (FATE#323432)
  - Legacy Module: OpenSSL 1.0.x Has Been Moved to the Legacy Module
    (FATE#323920)
* Mon Feb 26 2018 sknorr@suse.com
- 15.0.20180226
- Updated template text
- Updated release notes from FATE
- New entries:
  - Support for Scalable Machine Check Architecture (Scalable MCA)
    (FATE#322484)
  - x11vnc Has Been Removed (FATE#323207)
  - OpenSSL 1.0.x Has Been Moved to the Legacy Module (FATE#323920)
  - Reflink Feature of XFS Is Not Supported (FATE#324503)
- Changed entries:
  - ntpd Has Been Replaced With Chrony (FATE#323432)
* Mon Feb 12 2018 sknorr@suse.com
- 15.0.20180212
- Updated Makefile
- Updated template text
- Updated release notes from FATE
- New entries:
  - System Roles for SUSE Linux Enterprise Desktop (FATE#324198)
* Mon Jan 15 2018 sknorr@suse.com
- 15.0.20180115
- Updated release notes from FATE
- New entries:
  - System-wide Locale/Keymap/Font Settings are not read from
    /etc/sysconfig/ anymore (FATE#319454)
  - ntpd Has Been Replaced With Chrony (FATE#323432)
* Fri Oct 20 2017 sknorr@suse.com
- 15.0.20171020
- Updated template text
- Updated release notes from FATE
- New entries:
  - Wireshark Qt UI Replaces Deprecated GTK+ UI (FATE#323341)
  - No Default Compose Key Combination (FATE#324214)
* Fri Oct  6 2017 sknorr@suse.com
- 15.0.20171006
- Updated template text
  - Documentation URLs now point to beta.suse.com
  - Bug report links now allow reporting bugs for beta product
- Updated release notes from FATE
- New entries:
  - ReiserFS Support Removed (FATE#323394)
* Fri Aug 18 2017 sknorr@suse.com
- 15.0.20170818
- Initial version of SLED 15 release notes
- Updated release notes from FATE
- New entries:
  - GnuPG Uses SHA-2 Family of Digests by Default (FATE#323084)
* Fri Apr 28 2017 sknorr@suse.com
- 12.3.20170428
- Updated template text
  - Fixed release date
  - Added Package Hub and SDK to related products
- Updated release notes from FATE
- New entries:
  - Online Migration: Checking the Status of Registered Products
    (FATE#320534)
  - "Register Extensions or Modules Again" Has Been Removed from YaST
    (FATE#323343)
* Mon Mar  6 2017 sknorr@suse.com
- 12.3.20170306
- Updated Makefile
- Updated template text
  - Added information about release notes of skipped product versions
  - Fixed "SP3 SP1" snag (bsc#1021007)
* Tue Nov 15 2016 sknorr@suse.com
- Replace @VERSION@ with version number (bsc#1009221)
* Thu Nov 10 2016 sknorr@suse.com
- 12.3.20161110
- Updated template text
- Updated release notes from FATE
- Initial entry:
  - FATE#321767: YaST: Default Auto-Refresh Status for Local
    Repositories Is "Off"
* Fri Oct  7 2016 sknorr@suse.com
- 12.2.20161007 (for SLE 12 SP2 GMC)
- Updated template text
  - Updated life cycle info (bsc#999197)
- Updated release notes from FATE
- Changed entries:
  - FATE#320305: Incompatible Changes in the New 4.4 Kernel
  - FATE#320392: ntp 4.2.8
  - FATE#320958: AutoYaST: Applying the First-Stage Network
    Configuration to the Installed System
  - FATE#320973: systemd: Support for System V and LSB Init Scripts Has
    Been Moved Out of Core Daemon
  - FATE#321157: SASL Integration in sudo
* Fri Sep 16 2016 sknorr@suse.com
- 12.2.20160916
- Updated template text
- Updated release notes from FATE
- New entries:
  - FATE#319461: openldap2-ppolicy-check-password Has Been Added:
    OpenLDAP Password Strength Policy Enforcer
  - FATE#319716: Updating the Installer at the Beginning of the
    Installation or Upgrade
  - FATE#321157: SASL Integration in sudo
- Changed entries:
  - FATE#320305: Incompatible Changes in the New 4.4 Kernel
    [Added information about end_phys_index file]
* Fri Aug 26 2016 sknorr@suse.com
- 12.2.20160826 (for 12 SP2 RC2)
- Updated template text
  - Added section about related products
- Updated release notes from FATE
- New entries:
  - FATE#320018: Devilspie 2 Has Been Added
  - FATE#320305: Incompatible Changes in the New 4.4 Kernel
  - FATE#320330: Qt 5 Has Been Updated to 5.6.1
- Changed entries:
  - FATE#316813: Flash Player Has Been Removed
* Thu Aug  4 2016 sknorr@suse.com
- 12.2.20160804 (for 12 SP2 RC1)
- Updated Makefile from repository
- Updated template text
- Updated release notes from FATE
- New entries:
  - FATE#316813: Flash Player Has Been Removed
- Removed entries:
  - FATE#320254: IBM/Lenovo ThinkPad Laptops: Support for "Access
    IBM"/"ThinkVantage" Button Removed
    [Only relevant for x86 computers which are not supported by SLE]
* Fri Jul  1 2016 sknorr@suse.com
- 12.2.20160701
- Updated Makefile from repository
- Updated release notes from FATE
- New entries:
  - FATE#319675: OpenSSH Was Updated to Version 7.2
  - FATE#320958: AutoYaST: Applying the First-Stage Network
  Configuration to the Installed System
  - FATE#320973: systemd: Support for System V and LSB Init Scripts
    Has Been Moved Out of Core Daemon
- Changed entries:
  - FATE#320494: Media-based Sources Are Disabled After
    Installation If They Are Not Needed
* Mon Jun 13 2016 sknorr@novell.com
- 12.2.20160613 (for 12 SP2 Beta 3):
- Updated release notes from FATE
- New entries:
  FATE#320494, FATE#320541, FATE#317043, FATE#320900
- Removed entries:
  FATE#319961
* Tue May  3 2016 sknorr@suse.com
- 12.2.20160503:
- Updated release notes from FATE
  - New entries:
    FATE#320388, FATE#320111, FATE#320392,FATE#320254, FATE#319961,
    FATE#318930
- Updated Makefile from repo
* Mon Mar  7 2016 sknorr@suse.com
- 12.2.20160307:
- Initial version of release notes for 12 SP2
- Updated release notes from FATE
* Fri Mar  4 2016 sknorr@suse.com
- 12.1.20160304 (tracked in bsc#963397):
- Update release notes from FATE.
- New entries:
  - FATE#319118: Updating Registration Status
  - FATE#319388: Wireshark Updated
- Changed entries:
  - Some typo fixes in other entries
* Fri Jan 22 2016 sknorr@suse.com
- 12.1.20160122 (tracked in bsc#961132):
- Update release notes from FATE.
- New entries:
  - FATE#315161: New Method of Online Migration Between Service Packs
    (see: bsc#959576, bsc#959134)
  - FATE#320205: Using SSH-Based AutoYaST Without Doing Updates
    (see: bsc#959208)
- Changed entries:
  - FATE#318956: OpenJDK 8 availability: Clarification, language
    cleanup
  - Lots of other entries changed to improve spelling, grammar,
    terminology, and readability
* Thu Dec  3 2015 sknorr@suse.com
- Tracked in bsc#957800
- Update release notes from FATE.
- Added entries:
  - FATE#319930: Creating an AutoYaST XML File (bsc#956325)
- Changed entries:
  - FATE#319890: If You Are Using Proprietary Graphics Drivers, Perform
    an Online Upgrade (Behavior applies to all third-party KMPs)
* Fri Nov 20 2015 sknorr@suse.com
- 12.1.20151120 (tracked in bsc#956030):
- Update release notes from FATE.
- Added entries:
  - FATE#319890: If You Are Using Proprietary Graphics Drivers, Perform
    an Online Upgrade (for bsc#955523)
  - FATE#319108: Rollback of Service Packs
- Changed entries:
  - FATE#317085: CJK Languages Support in Text-mode Installation
    (formatting fixes)
  - FATE#319467: Return Codes of zypper
    (formatting fixes)
  - FATE#319391: Tar: extended attributes
    (moved to different category)
  - FATE#319317: Safer Btrfs Balance Operation
    (improved description)
  - FATE#318805: Creating New Subvolumes Underneath the /-hierarchy
    (formatting fixes)
  - FATE#318574: Password Protection Behavior for Boot Entries
    (formatting fixes)
  - FATE#319049: Upgrading PostgreSQL Installations from 9.1 to 9.4
    (formatting, grammar fixes)
  - FATE#319040: ntp 4.2.8
    (grammar fixes)
  - FATE#319418: Graphviz PDF output Requires X11
    (grammar, formatting fixes)
- Removed entries:
  - FATE#318413: fsadm now support btrfs filesystem
- Improved text output: Removed # characters at the end of section
  titles (bsc#955662)
* Fri Nov  6 2015 ke@suse.de
- 12.1.20151106 (bsc#933411):
- Update release notes from FATE.
* Thu Oct  8 2015 ke@suse.de
- 12.1.20151008 (bsc#933411):
- Update release notes from FATE.
* Mon Sep 14 2015 ke@suse.de
- 12.1.20150914 (bsc#933411):
- Update release notes from FATE.
- Fix .txt encoding and stop applying yast.xsl.
* Mon Aug 17 2015 ke@suse.de
- 12.1.20150817 (bsc#933411):
- Update release notes from FATE.
* Thu Jul 30 2015 ke@suse.de
- 12.1.20150730 (bsc#933411):
- Update release notes from FATE.
* Wed Jul 15 2015 ke@suse.de
- 12.1.20150715:
- Update release notes from FATE.
- Fix encoding (bsc#938049).
* Thu Jul  2 2015 ke@suse.de
- 12.1.20150702 (bsc#933411):
- Update release notes from FATE.
* Tue Jun  2 2015 ke@suse.de
- 12.1.20150602 (bsc#933411):
- Update release notes from FATE.
* Thu Feb 12 2015 ke@suse.de
- 12.1.20150212:
- Start with resetting for SLED 12 SP1.
* Mon Jan 19 2015 ke@suse.de
- 12.0.20150119 (bnc#912833):
- Update release notes from FATE.
- New entries: Deliver "parallel" implementations of compression
  software (fate#316220); SELinux is not supported on SUSE Linux
  Enterprise Desktop 12 (bnc#913516 via fate#318353).
* Thu Jan  8 2015 ke@suse.de
- 12.0.20150108 (bnc#911707):
- Update release notes from FATE.
- New entries: Drivers for Nvidia Graphical Chipsets (fate#316691);
  Connection to VNC support GNOME (fate#318311).
- 12.0.20141203 (bnc#904030):
- Update release notes from FATE.
- New entries: Autoselecting Packages during Module Activation
  (bnc#905802 via fate#318213); cifs-utils /etc/samba/smbfstab migration
  (bnc#903217 via fate#318090).
- Updated entries: Current Features and Limitations in a UEFI Secure
  Boot Context (bnc#896645 via fate#317500); "Enabling the wicked
  "nanny" Framework" (fate#316649); /proc/acpit/event Interface Removed
  (fate#317911).
* Tue Oct 28 2014 ke@suse.de
- 12.0.20141028 (bnc#900919):
- Update release notes from FATE.
- Fixed minor bugs: bnc#900771 (via fate#316585, typo); reference to
  conline documentation (bnc#900919).
* Fri Oct 10 2014 ke@suse.de
- 12.0.20141010:
- Update release notes from FATE.
- Update What's New: Info on fix status of bash (bnc#900057).
* Wed Oct  1 2014 ke@suse.de
- Update SLE 12 release notes from FATE.
- New entries: systemd: Activating a network.service Implementation
  (fate#317943).
* Mon Sep 29 2014 ke@suse.de
- 12.0.20140929:
- Update SLE 12 release notes from FATE.
- Updated entries: What's New (bnc#8981230).
* Thu Sep 25 2014 ke@suse.de
- 12.0.20140925:
- New entries: /dev/disk/by-path/ links no longer created for virtio
  devices (bnc#893728 via fate#317887 [probably already submitted last
  time); Firefox Integration in Active Directory Environments Using
  NTLMv1 Protocol (bnc#882670 via fate#317918).
* Thu Sep 18 2014 ke@suse.de
- 12.0.20140918:
- Update SLE 12 release notes from FATE.
* Thu Sep  4 2014 ke@suse.de
- 12.0.20140904:
- Update SLE 12 release notes from FATE.
* Thu Aug 28 2014 ke@suse.de
- 12.0.20140828:
- Update SLE 12 release notes from FATE.
* Thu Aug 21 2014 ke@suse.de
- 12.0.20140821:
- Update SLE 12 release notes from FATE.
* Thu Aug 14 2014 ke@suse.de
- 12.0.20140814:
- Update SLE 12 release notes from FATE.
- Improve support statement (bnc#882262).
* Mon Aug 11 2014 ke@suse.de
- 12.0.20140811:
- Update SLE 12 release notes from FATE.
- Add missing section (categories).
* Mon Aug  4 2014 rsalevsky@suse.com
- 12.0.20140804:
  * change date format
  * fix wrong version
* Mon Jul 28 2014 rsalevsky@suse.com
- 12.0.20140728:
  * New Makefile
* Fri Jul 25 2014 rsalevsky@suse.com
- 12.0.18
  * Update SLE 12 release notes from FATE.
* Thu Jul  3 2014 ke@suse.de
- 12.0.17:
- Update SLE 12 release notes from FATE.
- Switch to article layout.
* Wed Jun 18 2014 ke@suse.de
- 12.0.16:
- Update SLE 12 release notes from FATE.
* Thu Jun 12 2014 ke@suse.de
- 12.0.15:
- Update SLE 12 release notes from FATE.
* Mon Jun  2 2014 ke@suse.de
- 12.0.14:
- Update SLE 12 release notes from FATE.
* Thu May 15 2014 ke@suse.de
- 12.0.13:
- Update SLE 12 release notes from FATE.
* Wed Apr 30 2014 ke@suse.de
- 12.0.12:
- Update SLE 12 release notes from FATE.
- Updated entries: Kernel Modules (bnc#869159).
* Wed Apr 16 2014 rsalevsky@suse.com
- 12.0.11
- Update release notes from FATE.
- Cleanup specfile and fix build warning.
* Mon Apr  7 2014 ke@suse.de
- 12.0.10:
- Update release notes from FATE.
* Thu Mar 27 2014 ke@suse.de
- 12.0.9:
- Update release notes from FATE.
* Thu Mar 20 2014 ke@suse.de
- 12.0.8:
- Update SP3 release notes from FATE.
- Align structure with SLES release notes.
* Thu Mar 13 2014 ke@suse.de
- 12.0.7:
- Update SP3 release notes from FATE.
- Require dejavu-fonts and google-opensans-fonts.
* Wed Mar  5 2014 ke@suse.de
- 12.0.6:
- Update SP3 release notes from FATE.
- Avoid superfluous directory in release-notes-static (bnc#866876).
* Thu Feb 27 2014 ke@suse.de
- 12.0.5:
- Update SP3 release notes from FATE.
- Use yast.xsl to avoid setting docbook default
  body.attributes (bnc#864900).
* Thu Feb 13 2014 ke@suse.de
- 12.0.4:
- Update SP3 release notes from FATE.
* Thu Jan 30 2014 ke@suse.de
- 12.0.3:
- Update SP3 release notes from FATE.
- Install LICENSE.
* Fri Jan 24 2014 ke@suse.de
- 12.0.2:
- Use daps 2.0.x for building.
- Update SP3 release notes from FATE.
- Remove more obsolete entries.
- Change license from Any commercial to CC-BY-ND-3.0.
- Add license.
* Thu Jan  9 2014 ke@suse.de
- 12.0.1:
- Update SLED 12 release notes from FATE.
* Thu Dec 12 2013 ke@suse.de
- 12.0.0:
- Start resetting for SLED 12.
- Pull the SLED 12 release notes from FATE as a replacement for the SLED
  11 SP3 entries.
* Thu Nov 14 2013 ro@suse.de
- combining exclusivearch and noarch makes no sense
* Wed Sep 18 2013 ke@suse.de
- 11.3.23:
- Update SP3 release notes from FATE.
- Changed entry: FreeRDP Is Going to Replace rdesktop (bnc#836922, via
  fate#311422); Migrating to SLE 11 SP3 Using Zypper (bnc#838463).
* Tue Aug 27 2013 ke@suse.de
- 11.3.22 (bnc#833936):
- Update SP3 release notes from FATE.
- Changed entry: openJDK 7 as a Replacement for openJDK 6 (bnc#834910,
  via fate#313503).
* Thu Aug 22 2013 ke@suse.de
- 11.3.21 (bnc#833936):
- Update SP3 release notes from FATE.
- New entry: Migrating from SP2 to SP3 with YaST or the Update Applet
  (bnc#833591, Extras repo).
- Changed entry: Migrating to SLE 11 SP3 Using Zypper (bnc#833591,
  Extras repo).
* Thu Jul  4 2013 ke@suse.de
- 11.3.20 (bnc#:824787):
- Update SP3 release notes from FATE.
- New entries: Lower Version Numbers in SUSE Linux Enterprise 11 SP3
  than in SP2 (bnc#827325).
* Mon Jul  1 2013 ke@suse.de
- 11.3.19:
- Update SP3 release notes from FATE.
- Kernel version (bnc#827324).
* Mon Jun 17 2013 ke@suse.de
- 11.3.18 (bnc#825261):
- Update SP3 release notes from FATE.
* Mon May 27 2013 ke@suse.de
- 11.3.17:
- New entries: Package "biosdevname" in Techpreview (bnc#819910).
- Additional target (release-notes-static) for publishing on the Web
  using daps (bnc#821574).
- Use daps to build the PDF output format.
- Update SP3 release notes from FATE.
* Thu May 23 2013 ke@suse.de
- 11.3.16:
- Update SP3 release notes from FATE.
* Thu May 16 2013 ke@suse.de
- 11.3.15:
- Update SP3 release notes from FATE.
* Wed May  8 2013 ke@suse.de
- 11.3.14:
- Update SP3 release notes from FATE.
* Wed May  8 2013 ke@suse.de
- 11.3.13:
- Update SP3 release notes from FATE.
* Thu May  2 2013 ke@suse.de
- 11.3.13:
- Update SP3 release notes from FATE.
* Thu Apr 25 2013 ke@suse.de
- 11.3.12:
- Update SP3 release notes from FATE.
- Changed entries: Migrating to SLE 11 SP3 Using Zypper.
* Thu Apr 18 2013 ke@suse.de
- 11.3.11:
- Update SP3 release notes from FATE (now also with fates in state
  validation).
* Mon Apr 15 2013 ke@suse.de
- 11.3.10:
- Update SP3 release notes from FATE.
* Thu Apr  4 2013 ke@suse.de
- 11.3.9:
- Update SP3 release notes from FATE.
* Thu Mar 28 2013 ke@suse.de
- 11.3.8:
- Update SP3 release notes from FATE.
* Thu Mar 21 2013 ke@suse.de
- 11.3.7:
- Update SP3 release notes from FATE.
* Fri Mar 15 2013 ke@suse.de
- 11.3.6:
- Update SP3 release notes from FATE.
* Thu Mar  7 2013 ke@suse.de
- 11.3.5:
- Update SP3 release notes from FATE.
* Wed Feb 27 2013 ke@suse.de
- 11.3.4:
- Update SP3 release notes from FATE.
* Thu Feb  7 2013 ke@suse.de
- 11.3.3:
- Improve sectioning.
- Update SP3 release notes from FATE.
* Thu Feb  7 2013 ke@suse.de
- 11.3.2:
- Update SP3 release notes from FATE.
* Thu Jan 31 2013 ke@suse.de
  11.3.1:
- Update SP3 release notes from FATE.
* Tue Dec  4 2012 ke@suse.de
- 11.3.0:
- Start resetting for SLED 11 SP3.
- Pull in SP3 release notes from FATE as a replacement for the SP2
  entries.
* Thu Aug 16 2012 ke@suse.de
- 11.2.26:
- Update SP2 release notes from FATE.
- New entries: Support for Universal Serial Bus Version 3.0
  (USB 3.0) (bnc#774670, via fate#311827); Upgrading PostgreSQL
  Installations from 8.3 to 9.1 (fate#11794).
* Wed Apr 18 2012 ke@suse.de
- 11.2.25 (bnc#750728):
- Update SP2 release notes from FATE.
- Installing icedteaweb-plugin manually (bnc#748834).
* Wed Mar 14 2012 ke@suse.de
- 11.2.24:
- Update SP2 release notes from FATE.
- Remove now confusing gfdl license file; cf. .changes entry
  from 2007-07-10.
* Tue Mar  6 2012 ke@suse.de
- 11.2.23:
- Update SP2 release notes from FATE.
- Updated entries: Migrating to SLE 11 SP2 Using Zypper (bnc#731924).
- Other fixes: bnc#749380; bnc#747622 (Gnome and KDE version, remove
  statement about java plug-in).
* Wed Feb 15 2012 ke@suse.de
- 11.2.22:
- Update SP2 release notes from FATE.
- Tools for handling NFSv4 ACLs (bnc#714032).
* Mon Feb  6 2012 ke@suse.de
- 11.2.21:
- Update SP2 release notes from FATE.
- Add missing sections.
* Fri Feb  3 2012 ke@suse.de
- 11.2.20:
- Update SP2 release notes from FATE.
* Thu Feb  2 2012 ke@suse.de
- 11.2.19:
- Update SP2 release notes from FATE.
- New entry: Migrating to SLE 11 SP2 (bnc#731924)
* Fri Jan 27 2012 ke@suse.de
- - 11.2.18:
- Update SP2 release notes from FATE.
* Mon Jan 16 2012 ke@suse.de
- 11.2.16:
- Update SP2 release notes from FATE.
* Fri Jan 13 2012 ke@suse.de
- 11.2.15:
- Update SP2 release notes from FATE.
* Thu Jan  5 2012 ke@suse.de
- 11.2.14:
- Update SP2 release notes from FATE.
- Expand entities in title (bnc#738002).
* Wed Dec 28 2011 ke@suse.de
- 11.2.13:
- Update SP2 release notes from FATE.
* Wed Dec 14 2011 ke@suse.de
- 11.2.12:
- Update and now restructure SP2 release notes from FATE.
- Myri10GE driver (bnc#736148).
* Thu Dec  1 2011 ke@suse.de
- 11.2.11:
- Start with general cleanup.
- Import and update SP2 release notes from FATE.
* Mon Nov 28 2011 ke@suse.de
- 11.2.10:
- Resolve some novell/suse references.
* Thu Nov 24 2011 ke@suse.de
- 11.2.9:
- Import and update SP2 release notes from FATE.
* Fri Nov 18 2011 ke@suse.de
- 11.2.8:
- Import and update SP2 release notes from FATE.
* Fri Oct 28 2011 ke@suse.de
- 11.2.7:
- Import and update SP2 release notes from FATE.
* Fri Sep 16 2011 ke@suse.de
- 11.2.5:
- Import and update SP2 release notes from FATE.
* Fri Sep  9 2011 ke@suse.de
- 11.2.5:
- Import and update SP2 release notes from FATE.
- Drop the _SPx suffix from the installation directory (bnc#716592).
* Thu Sep  1 2011 ke@suse.de
- 11.2.4:
- Import and update SP2 release notes from FATE.
- Fix bnc#714616.
* Fri Aug 26 2011 ke@suse.de
- 11.2.3:
- Import and update SP2 release notes from FATE.
- Provide date info.
* Fri Jul 29 2011 ke@suse.de
- 11.2.2:
- Import and update SP2 release notes from FATE.
- Remove unwanted SDK entries.
* Thu Jul 28 2011 ke@suse.de
- 11.2.1:
- Removed packages: amor (fate#312415).
- Import and update SP2 release notes from FATE.
* Mon Jul  4 2011 ke@suse.de
- 11.2.0:
- Add release notes entries from FATE.
* Fri May 13 2011 ke@suse.de
- 11.1.7:
- Java Plugin in x86_64 (bnc#492912).
* Tue Apr 19 2011 ke@suse.de
-11.1.6:
- Stopping Cron Status Messages (bnc#622203)
* Fri Mar 11 2011 ke@suse.de
- 11.1.5:
  * Replacing OOo with LibreOffice (bnc#678116).
* Mon Jun 28 2010 ke@suse.de
- 11.1.4:
  * Remove more character references (bnc#596832).
* Mon Jun 14 2010 ke@suse.de
- 11.1.3:
- Also recode .txt to ascii (bnc#596832).  Remove obsolete
  rns-recode-txt.patch.
- New entries: Boot Device Larger Than 2 TiB (bnc#604766).
* Mon May 10 2010 ke@suse.de
- rns-recode-txt.patch: Also recode .txt to ascii doing the html dump
  (bnc#596832).
* Fri Mar 19 2010 ke@suse.de
- 11.1.2:
- New entries: Kopete no longer supports IRC (bnc#584179), Graphics
  Drivers Using KMS (bnc#571859).
- Dropped entries: Puppet no longer tech preview (bnc#588793).
* Fri Mar  5 2010 ke@suse.de
- Fix encoding problem in .txt files (bnc#575693).
* Tue Feb  2 2010 ke@suse.de
- 11.1.1:
- Fix © symbol; bnc#573914.
* Fri Jan 22 2010 ro@suse.de
- added exclusivearch
* Thu Jan 21 2010 ke@suse.de
  11.1.0:
- Modify the package structure to make it similar to the
  release-notes-sles package (bnc#571857).
- Update entries to match forthcoming SLED11 SP1 release; provided by
  Stefan Behlert (bnc#571857).
- New entry: KDE 4 update (bnc#558704).
* Wed Jul  1 2009 ke@suse.de
  11.0.21:
- Add note on KDE 4 update (bnc#426160).
- Wireshark (bnc#460765).
* Tue May 12 2009 ke@suse.de
- 11.0.20:
  * Describe Documentation shipped with SLED11 (bnc#490177).
  * Java Plugin in x86_64 (bnc#492912).
  * Update info on Pulseaudio (bnc#456802).
* Wed Mar 25 2009 ke@suse.de
  11.0.19:
  * Correct coppyright date; reported by Jun Hui Wang (bnc#484606).
  * Fix wording (Mike Bowling); reported by Camille Hill (bnc#479253).
* Wed Mar 18 2009 ke@suse.de
- 11.0.18:
  * Fix formatting: map "screen" elements to "pre" tags to enforce proper
  line-breaks; reported by Heiko Rommel [bnc#486425].
  * Replace wrong kernel name: kernel-pae instead of kernel-bigsmp;
  reported by Heiko Rommel [bnc#486428].
* Thu Mar 12 2009 ke@suse.de
- 11.0.17
  * New entries: Networking issues (bnc#479546).
  * Enhance snippet on CJK language support (bnc#484634).
  * Fix typos: bnc#449095, bnc#479250.
* Tue Mar  3 2009 ke@suse.de
- 11.0.16:
  New entry: XEN as technology preview.
* Fri Feb 27 2009 behlert@suse.de
- 11.0.15:
  New entry: Java plugin issues; bnc#478739.
* Wed Feb 25 2009 ke@suse.de
- 11.0.14:
  New entry: CJK language support during installation; bnc#449095.
* Thu Feb 19 2009 ke@suse.de
- 11.0.13:
  New entry: GroupWise 8 client.
* Fri Feb 13 2009 ke@suse.de
- 11.0.12:
  * New entry: Setting hostname by DHCP (bnc#459762).
* Wed Jan 21 2009 ke@suse.de
- 11.0.11:
  Fix URL; bnc#450908.
* Mon Jan 12 2009 ke@suse.de
- 11.0.9:
  * Update by Stefan Behlert; bnc#465352:
  - patch the description according to Grant Ho
  - update technologie preview section (reordered, updated)
* Mon Dec  8 2008 ke@suse.de
- 11.0.9:
  * Major update by Stefan Behlert; bnc#456763:
  remove outdated entries, layout changes, add information on deprecated
  features, edit general introduction, and clarify snippet on unsupported
  modules.
* Thu Dec  4 2008 ke@suse.de
- 11.0.8:
  * Major update by Stefan Behlert towards SLED11 RC; bnc#450904.
* Fri Nov 28 2008 ke@suse.de
- 11.0.7:
  * New entries: sync with SLES release notes (by Stefan Behlert); Atheros
  Wireless Cards (bnc#418575).
* Fri Nov 14 2008 mrueckert@suse.de
- drop unneeded conditionals on sles_version
* Mon Nov 10 2008 ke@suse.de
- 11.0.5
  * Remove auto-suspendig snippet (bnc#439980).
* Fri Nov  7 2008 ke@suse.de
- 11.0.4
  * Add more entries: netconfig utility (bnc#440143); Auto-suspendig the
  System (bnc#439980).
* Fri Oct 24 2008 ke@suse.de
- 11.0.3
  * Add more entries: Do not close lid during installation (bnc#436939),
  devel packages moved to SDK (bnc#426161), dropping lprng in SLE12
  (bnc#413591).
* Fri Aug 15 2008 ke@suse.de
- 10.0.2:
  * Revert file names to plain RELEASE-NOTES basenames; reported by Stefan
  Behlert.
* Wed Aug 13 2008 ke@suse.de
- 11.0.1:
  * Implement the translation related infrastructure again; mostly copied
  from release-notes-openSUSE.
* Wed Jul 30 2008 behlert@suse.de
- update to SLED 11, initial release
- made the whole package similiar to release-notes-sles for easier
  maintenance
* Tue Jul 10 2007 gekker@suse.de
- Change the license to GFDL and install the COPYING file (#277389)
* Thu Jul  6 2006 gekker@suse.de
- Update release notes (#174589)
* Tue Jun 27 2006 gekker@suse.de
- Update with final release notes from etobiasson
- Update translations for de es fr hu it ja pt_BR zh_CN zh_TW
* Tue Jun 20 2006 gekker@suse.de
- Update release notes to include fix for (#186594)
- Fix formatting of release notes, encode in utf-8 (#186595)
* Mon Jun 19 2006 gekker@suse.de
- Updated release notes from etobiasson
* Mon Jun 19 2006 lrupp@suse.de
- renamed desktop-file (try to fix #185665)
* Fri Jun 16 2006 gekker@suse.de
- Update translations for ja
* Thu Jun  8 2006 gekker@suse.de
- Update release notes for etobiasson
- Fix formatting issuse (#182678)
* Tue Jun  6 2006 gekker@suse.de
- Fix to install the en release-notes again
* Mon Jun  5 2006 gekker@suse.de
- Update release notes for etobiasson
* Fri Jun  2 2006 gekker@suse.de
- Update translations for cd,de,es,fi,fr,hu,it,pt_BR,zh_CN,zh_TW
* Mon May 22 2006 gekker@suse.de
- Fix to still install the en release notes
* Mon May 22 2006 gekker@suse.de
- Update release notes
* Tue Mar 28 2006 gekker@suse.de
- Add information for installing ConsoleOne
* Mon Mar 27 2006 gekker@suse.de
- Initial import of release notes for SLED
